@@ -1,5 +1,5 @@
-# GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# GNU Solfege - free ear training software
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,6 +29,8 @@ import gu
 from osutils import *
 
 def linux_play_wav_file(filename):
+    if not cfg.get_string('sound/wav_player'):
+        raise ExecutableDoesNotExist('')
     run_external_program(cfg.get_string('sound/wav_player'), "", filename)
 
 def linux_play_midi_file(filename):
