@@ -12,6 +12,8 @@ if os.path.split(os.getcwd())[-1] == 'src':
 else:
     sys.path.insert(0, ".")
 
+import src.cfg
+src.cfg.initialise("default.config", None, "test-setup.cfg")
 import src.i18n
 
 if os.path.split(os.getcwd())[-1] == 'src':
